@@ -1,11 +1,12 @@
 """
 Moonstream database connection.
 """
-from contextlib import contextmanager
 import os
+from contextlib import contextmanager
+from typing import Generator
 
 from sqlalchemy import create_engine
-from sqlalchemy.orm import sessionmaker, Session
+from sqlalchemy.orm import Session, sessionmaker
 
 MOONSTREAM_DB_URI = os.environ.get("MOONSTREAM_DB_URI")
 if MOONSTREAM_DB_URI is None:
@@ -60,7 +61,7 @@ engine = create_moonstream_engine(
 SessionLocal = sessionmaker(bind=engine)
 
 
-def yield_db_session() -> Session:
+def yield_db_session() -> Generator[Session, None, None]:
     """
     Yields a database connection (created using environment variables).
     As per FastAPI docs:
@@ -84,7 +85,7 @@ RO_engine = create_moonstream_engine(
 RO_SessionLocal = sessionmaker(bind=RO_engine)
 
 
-def yield_db_read_only_session() -> Session:
+def yield_db_read_only_session() -> Generator[Session, None, None]:
     """
     Yields a database connection (created using environment variables).
     As per FastAPI docs:
